
=============================
Django EL(Endless) Pagination
=============================
.. image:: https://travis-ci.org/shtalinberg/django-el-pagination.svg?branch=develop
    :target: https://travis-ci.org/shtalinberg/django-el-pagination

.. image:: https://img.shields.io/pypi/v/django-el-pagination.svg
    :target:  https://pypi.python.org/pypi/django-el-pagination/

.. image:: https://img.shields.io/pypi/pyversions/django-el-pagination.svg

.. image:: https://img.shields.io/badge/django-1.8%20or%20newer-green.svg

.. image:: https://img.shields.io/pypi/dm/django-el-pagination.svg
    :target:  https://pypi.python.org/pypi/django-el-pagination/


Django EL(Endless) Pagination can be used to provide Twitter-style or
Digg-style pagination, with optional Ajax support and other features
like multiple or lazy pagination.

This app **django-el-pagination** forked from django-endless-pagination==2.0 (https://github.com/frankban/django-endless-pagination)
From version 3.0.0 drop support Django<1.8. For support Django<1.8 use django-endless-pagination==2.x.x

The initial idea, which has guided the development of this application,
is to allow pagination of web contents in `very few steps
<http://django-el-pagination.readthedocs.org/en/latest/start.html>`_.

**Documentation** is `avaliable online
<http://django-el-pagination.readthedocs.org/>`_, or in the doc
directory of the project.

To file **bugs and requests**, please use
https://github.com/shtalinberg/django-el-pagination/issues.

The **source code** for this app is hosted at
https://github.com/shtalinberg/django-el-pagination.

Pull requests are welcome. See 
<http://django-el-pagination.readthedocs.io/en/latest/contributing.html>`_.

